@@ -24,9 +24,8 @@
 
 /* check_mandirs.c */
 extern void test_manfile (const char *file, const char *path);
-extern void update_db_time (void);
-extern void reset_db_time (void);
 extern int create_db (const char *manpath, const char *catpath);
 extern int update_db (const char *manpath, const char *catpath);
 extern void purge_pointers (const char *name);
-extern int purge_missing (const char *manpath, const char *catpath);
+extern int purge_missing (const char *manpath, const char *catpath,
+			  int will_run_mandb);
