@@ -64,15 +64,6 @@ accessdb_filter () {
 		sed 's/\(-> "[^ ][^ ]* [^ ][^ ]* [^ ][^ ]* \)[^ ][^ ]* [^ ][^ ]* /\1MTIME /'
 }
 
-next_second () {
-	[ "$STAT_HAS_NSEC" != yes ] || return
-	startdate="$(date +%s)"
-	while :; do
-		sleep 1
-		[ "$(date +%s)" = "$startdate" ] || break
-	done
-}
-
 expect_pass () {
 	ret=0
 	eval "$2" || ret=$?
